@@ -8,7 +8,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
 use namespace::clean;
 use Data::Section -setup;
 
-our $VERSION = '0.033';
+our $VERSION = '0.034';
 
 sub configure {
 	my $self = shift;
@@ -353,6 +353,11 @@ haven't already installed them with cpanm:
 
     $ dzil listdeps --missing --develop | cpanm
 
+You can instead combine these two steps into one command by installing
+Dist::Zilla::App::Command::installdeps then running:
+
+    $ dzil installdeps
+
 Once everything is installed, here are some dzil commands you might try:
 
     $ dzil build
